@@ -25,6 +25,7 @@ KNOWN_ATTRIBUTES = (
     'dns_nameservers',
     'enable_dhcp',
     'enable_ndp_proxy',
+    'external_gateways',
     'fixed_ips',
     'gateway_ip',
     'host_routes',
@@ -82,6 +83,7 @@ KNOWN_EXTENSIONS = (
     'agent',
     'agent-resources-synced',
     'allowed-address-pairs',
+    'allowed-address-pairs-atomic',
     'auto-allocated-topology',
     'availability_zone',
     'binding',
@@ -92,6 +94,8 @@ KNOWN_EXTENSIONS = (
     'dns-domain-ports',
     'dns-integration',
     'dvr',
+    'enable-default-route-ecmp',
+    'enable-default-route-bfd',
     'empty-string-filtering',
     'expose-l3-conntrack-helper',
     'expose-port-forwarding-in-fip',
@@ -118,6 +122,7 @@ KNOWN_EXTENSIONS = (
     'metering',
     'metering_source_and_destination_filters',
     'multi-provider',
+    'external-gateway-multihoming',
     'net-mtu',
     'network-ip-availability',
     'network-segment-range',
@@ -140,6 +145,11 @@ KNOWN_EXTENSIONS = (
     'qos-rules-alias',
     'quotas',
     'quota-check-limit',
+    'quota-check-limit-default',
+    'port-hints',
+    'port-hint-ovs-tx-steering',
+    'port-numa-affinity-policy',
+    'port-numa-affinity-policy-socket',
     'rbac-address-group',
     'rbac-address-scope',
     'rbac-bgpvpn',
@@ -154,6 +164,7 @@ KNOWN_EXTENSIONS = (
     'sort-key-validation',
     'sorting',
     'standard-attr-description',
+    'standard-attr-fwaas-v2',
     'standard-attr-revisions',
     'standard-attr-segment',
     'standard-attr-timestamp',
@@ -165,8 +176,11 @@ KNOWN_EXTENSIONS = (
     'subnet-segmentid-enforce',
     'subnet-segmentid-writable',
     'tag',
+    'tag-creation',
     'trunk',
     'trunk-details',
+    'uplink-status-propagation',
+    'uplink-status-propagation-updatable',
     # Add here list of extensions with pointers to the project repo, e.g.
     'bgp',  # https://opendev.org/openstack/neutron-dynamic-routing
 
@@ -189,6 +203,8 @@ KNOWN_EXTENSIONS = (
 
     # https://opendev.org/openstack/tap-as-a-service
     'taas',
+    'tap-mirror',
+    'tap-mirror-both-direction',
     'taas-vlan-filter',
 )
 
