@@ -14,7 +14,6 @@
 #    under the License.
 
 import abc
-import typing
 
 from neutron_lib._i18n import _
 from neutron_lib import constants
@@ -184,7 +183,7 @@ class APIExtensionDescriptor(ExtensionDescriptor):
     If extension implementations need to override the default behavior of
     this class they can override the respective method directly.
     """
-    api_definition: typing.Union[constants.Sentinel, object] = _UNSET
+    api_definition: constants.Sentinel | object = _UNSET
 
     @classmethod
     def _assert_api_definition(cls, attr=None):
