@@ -41,6 +41,7 @@ INACTIVE = "INACTIVE"
 ERROR = "ERROR"
 
 DEVICE_OWNER_COMPUTE_PREFIX = "compute:"
+DEVICE_OWNER_MANILA_PREFIX = "manila:"
 DEVICE_OWNER_NETWORK_PREFIX = "network:"
 DEVICE_OWNER_NEUTRON_PREFIX = "neutron:"
 DEVICE_OWNER_BAREMETAL_PREFIX = "baremetal:"
@@ -61,10 +62,10 @@ DEVICE_OWNER_AGENT_GW = (DEVICE_OWNER_NETWORK_PREFIX +
 DEVICE_OWNER_ROUTER_SNAT = (DEVICE_OWNER_NETWORK_PREFIX +
                             "router_centralized_snat")
 DEVICE_OWNER_ROUTED = (DEVICE_OWNER_NETWORK_PREFIX + "routed")
-# TODO(johnsom) Remove after these stop being used. Neutron-LBaaS is now
-#               retired (train) and these should no longer be necessary.
-DEVICE_OWNER_LOADBALANCER = DEVICE_OWNER_NEUTRON_PREFIX + "LOADBALANCER"
-DEVICE_OWNER_LOADBALANCERV2 = DEVICE_OWNER_NEUTRON_PREFIX + "LOADBALANCERV2"
+DEVICE_OWNER_VPN_ROUTER_GW = (DEVICE_OWNER_NETWORK_PREFIX +
+                              "vpn_router_gateway")
+DEVICE_OWNER_VPN_TRANSIT_NETWORK = (DEVICE_OWNER_NETWORK_PREFIX +
+                                    "vpn_namespace")
 
 # Device owner for distributed services (e.g OVN Metadata/DHCP).
 DEVICE_OWNER_DISTRIBUTED = DEVICE_OWNER_NETWORK_PREFIX + "distributed"
@@ -82,6 +83,23 @@ ROUTER_INTERFACE_OWNERS_SNAT = (DEVICE_OWNER_ROUTER_INTF,
                                 DEVICE_OWNER_DVR_INTERFACE,
                                 DEVICE_OWNER_ROUTER_SNAT)
 
+DEVICE_OWNER_DEFAULT = ''
+NO_PROVISIONING_BLOCKS_OWNERS = (DEVICE_OWNER_DEFAULT,
+                                 DEVICE_OWNER_DVR_INTERFACE,
+                                 DEVICE_OWNER_HA_REPLICATED_INT,
+                                 DEVICE_OWNER_ROUTER_INTF,
+                                 DEVICE_OWNER_ROUTER_GW,
+                                 DEVICE_OWNER_ROUTER_SNAT,
+                                 DEVICE_OWNER_DHCP,
+                                 DEVICE_OWNER_AGENT_GW,
+                                 DEVICE_OWNER_ROUTER_HA_INTF,
+                                 DEVICE_OWNER_FLOATINGIP)
+
+DHCP_CONFIG_NOT_REQUIRED_OWNERS = (DEVICE_OWNER_ROUTER_HA_INTF,
+                                   DEVICE_OWNER_FLOATINGIP,
+                                   DEVICE_OWNER_DHCP,
+                                   DEVICE_OWNER_DISTRIBUTED)
+
 DEVICE_ID_RESERVED_DHCP_PORT = 'reserved_dhcp_port'
 
 FLOATINGIP_KEY = '_floatingips'
@@ -103,8 +121,16 @@ IPv4_ANY = '0.0.0.0/0'
 IPv6_ANY = '::/0'
 IP_ANY = {IP_VERSION_4: IPv4_ANY, IP_VERSION_6: IPv6_ANY}
 
+IPv4_NETWORK_BROADCAST = "255.255.255.255"
+
 IPv6_LLA_PREFIX = 'fe80::/64'
 
+LOCALHOST_IP_ADDRESSES = ('127.0.0.1', '::1')
+
+# All_DHCP_Relay_Agents_and_Servers
+# [RFC8415] https://datatracker.ietf.org/doc/html/rfc8415
+IPv6_ALL_DHCP_RELAY_AGENTS_AND_SERVERS = "ff02::1:2"
+
 DHCP_CLIENT_PORT = 68
 DHCP_RESPONSE_PORT = 67
 DHCPV6_CLIENT_PORT = 546
@@ -122,6 +148,7 @@ AGENT_PROCESS_METERING = 'neutron-metering-agent'
 AGENT_PROCESS_NIC_SWITCH = 'neutron-sriov-nic-agent'
 AGENT_PROCESS_OVN_METADATA = 'neutron-ovn-metadata-agent'
 AGENT_PROCESS_OVS = 'neutron-openvswitch-agent'
+AGENT_PROCESS_OVN = 'neutron-ovn-agent'
 
 AGENT_TYPE_DHCP = 'DHCP agent'
 AGENT_TYPE_L3 = 'L3 agent'
@@ -147,6 +174,8 @@ L3_AGENT_SCHEDULER_EXT_ALIAS = 'l3_agent_scheduler'
 DHCP_AGENT_SCHEDULER_EXT_ALIAS = 'dhcp_agent_scheduler'
 L3_DISTRIBUTED_EXT_ALIAS = 'dvr'
 L3_HA_MODE_EXT_ALIAS = 'l3-ha'
+L3_ENABLE_DEFAULT_ROUTE_ECMP_ALIAS = 'enable-default-route-ecmp'
+L3_ENABLE_DEFAULT_ROUTE_BFD_ALIAS = 'enable-default-route-bfd'
 SUBNET_ALLOCATION_EXT_ALIAS = 'subnet_allocation'
 
 # Protocol names and numbers for Security Groups/Firewalls
@@ -312,11 +341,21 @@ ACTIVE_PENDING_STATUSES = (
 TYPE_FLAT = 'flat'
 TYPE_GENEVE = 'geneve'
 TYPE_GRE = 'gre'
+TYPE_GRE_IP6 = 'ip6gre'
 TYPE_LOCAL = 'local'
 TYPE_VXLAN = 'vxlan'
 TYPE_VLAN = 'vlan'
 TYPE_NONE = 'none'
 
+TYPE_PHYSICAL = [TYPE_FLAT,
+                 TYPE_VLAN,
+                 ]
+TYPE_TUNNELLED = [TYPE_GENEVE,
+                  TYPE_GRE,
+                  TYPE_GRE_IP6,
+                  TYPE_VXLAN,
+                  ]
+
 # List of supported network segment range types
 NETWORK_SEGMENT_RANGE_TYPES = [TYPE_VLAN, TYPE_VXLAN, TYPE_GRE, TYPE_GENEVE]
 
@@ -350,14 +389,13 @@ DNS_DOMAIN_DEFAULT = 'openstacklocal.'
 DNS_LABEL_KEYWORDS = ['project_id', 'project_name', 'user_name', 'user_id']
 DNS_LABEL_MAX_LEN = 63
 DNS_LABEL_REGEX = "^([a-z0-9-]{1,%d}|%s)$" % (
-                   DNS_LABEL_MAX_LEN,
-                   '<' + '>|<'.join(DNS_LABEL_KEYWORDS) + '>')
+    DNS_LABEL_MAX_LEN, '<' + '>|<'.join(DNS_LABEL_KEYWORDS) + '>')
 
 # max value for TCP, UDP, SCTP ports
 PORT_MAX = 2**16 - 1
 
 VALID_DSCP_MARKS = [0, 8, 10, 12, 14, 16, 18, 20, 22, 24, 26, 28, 30, 32, 34,
-                    36, 38, 40, 46, 48, 56]
+                    36, 38, 40, 44, 46, 48, 56]
 
 INGRESS_DIRECTION = 'ingress'
 EGRESS_DIRECTION = 'egress'
@@ -380,8 +418,9 @@ TC_QDISC_PARENTS = {'root': 0xffffffff,
                     'ingress': 0xfffffff1}
 
 
-class Sentinel(object):
+class Sentinel:
     """A constant object that does not change even when copied."""
+
     def __deepcopy__(self, memo):
         # Always return the same object because this is essentially a constant.
         return self
@@ -579,6 +618,7 @@ RPC_NAMESPACE_RESOURCES = None
 
 # Default network MTU value when not configured
 DEFAULT_NETWORK_MTU = 1500
+IPV4_MIN_MTU = 68
 IPV6_MIN_MTU = 1280
 
 ROUTER_MARK_MASK = "0xffff"
@@ -624,7 +664,7 @@ METADATA_V4_CIDR = '169.254.169.254/32'
 METADATA_V4_SUBNET = '169.254.0.0/16'
 
 METADATA_V6_IP = 'fe80::a9fe:a9fe'
-METADATA_V6_CIDR = 'fe80::a9fe:a9fe/64'
+METADATA_V6_CIDR = 'fe80::a9fe:a9fe/128'
 
 METADATA_PORT = 80
 
@@ -663,6 +703,7 @@ NO_ACTIVE_BINDING = 'no_active_binding'
 EXT_PARENT_PREFIX = 'ext_parent'
 
 RP_BANDWIDTHS = 'resource_provider_bandwidths'
+RP_HYPERVISORS = 'resource_provider_hypervisors'
 RP_INVENTORY_DEFAULTS = 'resource_provider_inventory_defaults'
 RP_PP_WITHOUT_DIRECTION = (
     'resource_provider_packet_processing_without_direction')
@@ -674,12 +715,15 @@ RP_PP_INVENTORY_DEFAULTS = (
 PORT_NUMA_POLICY_REQUIRED = 'required'
 PORT_NUMA_POLICY_PREFERRED = 'preferred'
 PORT_NUMA_POLICY_LEGACY = 'legacy'
-PORT_NUMA_POLICIES = (PORT_NUMA_POLICY_REQUIRED, PORT_NUMA_POLICY_PREFERRED,
-                      PORT_NUMA_POLICY_LEGACY)
+PORT_NUMA_POLICY_SOCKET = 'socket'
+PORT_NUMA_POLICIES = (PORT_NUMA_POLICY_REQUIRED,
+                      PORT_NUMA_POLICY_PREFERRED,
+                      PORT_NUMA_POLICY_LEGACY,
+                      PORT_NUMA_POLICY_SOCKET,
+                      )
 
 # RBAC Sharing Actions
 ACCESS_SHARED = 'access_as_shared'
-ACCESS_READONLY = 'access_as_readonly'
 ACCESS_EXTERNAL = 'access_as_external'
 
 # neutron-dynamic-routing constants
@@ -688,3 +732,8 @@ MAX_ASNUM = 65535
 MAX_4BYTE_ASNUM = 4294967295
 
 SUPPORTED_AUTH_TYPES = ['none', 'md5']
+
+# Hardware offload types.
+HWOL_TYPE_SWITCHDEV = 'switchdev'
+VALID_HWOL_TYPES = (HWOL_TYPE_SWITCHDEV,
+                    )
