@@ -37,11 +37,13 @@ _model_query_hooks = {
     #                         'query': query_hook,
     #                         'filter': filter_hook,
     #                         'result_filters': result_filters
+    #                         'rbac_actions': rbac_actions
     #              },
     #              hook2: {
     #                         'query': query_hook,
     #                         'filter': filter_hook,
     #                         'result_filters': result_filters
+    #                         'rbac_actions': rbac_actions
     #              },
     #              ...
     #          },
@@ -50,11 +52,13 @@ _model_query_hooks = {
     #                         'query': query_hook,
     #                         'filter': filter_hook,
     #                         'result_filters': result_filters
+    #                         'rbac_actions': rbac_actions
     #              },
     #              hook2: {
     #                         'query': query_hook,
     #                         'filter': filter_hook,
     #                         'result_filters': result_filters
+    #                         'rbac_actions': rbac_actions
     #              },
     #              ...
     #          },
@@ -63,18 +67,20 @@ _model_query_hooks = {
 
 
 def register_hook(model, name, query_hook, filter_hook,
-                  result_filters=None):
+                  result_filters=None, rbac_actions=None):
     """Register a hook to be invoked when a query is executed.
 
     Adds the hook components to the _model_query_hooks dict. Models are the
     keys of this dict, whereas the value is another dict mapping hook names
-    to callables performing the hook.
+    to callables performing the hook or in the case of ``rbac_actions``, a set
+    of RBAC actions to filter the model.
 
     :param model: The DB Model that the hook applies to.
     :param name: A name for the hook.
     :param query_hook: The method to be called to augment the query.
     :param filter_hook: A method to be called to augment the query filter.
     :param result_filters: A Method to be called to filter the query result.
+    :param rbac_actions: An iterable of RBAC actions or a single one (string).
     :returns: None.
     """
     if callable(query_hook):
@@ -83,10 +89,16 @@ def register_hook(model, name, query_hook, filter_hook,
         filter_hook = helpers.make_weak_ref(filter_hook)
     if callable(result_filters):
         result_filters = helpers.make_weak_ref(result_filters)
+    if rbac_actions is not None:
+        if isinstance(rbac_actions, set | list | tuple):
+            rbac_actions = set(rbac_actions)
+        else:
+            rbac_actions = {rbac_actions}
     _model_query_hooks.setdefault(model, {})[name] = {
         'query': query_hook,
         'filter': filter_hook,
-        'result_filters': result_filters
+        'result_filters': result_filters,
+        'rbac_actions': rbac_actions,
     }
 
 
@@ -99,6 +111,26 @@ def get_hooks(model):
     return _model_query_hooks.get(model, {}).values()
 
 
+def get_rbac_actions(model):
+    """Retrieve and combine all RBAC actions requested in a model
+
+    :param model: The DB Model to look up for query hooks.
+    :returns: A set of RBAC actions defined in the model or the default RBAC
+              actions ('access_as_shared', 'access_as_readonly')
+    """
+    rbac_actions = None
+    for hook in get_hooks(model):
+        hook_rbac_actions = hook.get('rbac_actions')
+        if hook_rbac_actions is not None:
+            if rbac_actions is None:
+                rbac_actions = set()
+            rbac_actions.update(hook_rbac_actions)
+    return (
+        rbac_actions if rbac_actions is not None else
+        {constants.ACCESS_SHARED}
+    )
+
+
 def query_with_hooks(context, model, field=None, lazy_fields=None):
     """Query with hooks using the said context and model.
 
@@ -108,6 +140,7 @@ def query_with_hooks(context, model, field=None, lazy_fields=None):
     :param lazy_fields: list of fields for lazy loading
     :returns: The query with hooks applied to it.
     """
+    group_by = None
     if field:
         if hasattr(model, field):
             field = getattr(model, field)
@@ -124,16 +157,20 @@ def query_with_hooks(context, model, field=None, lazy_fields=None):
             query = query.outerjoin(model.rbac_entries)
             rbac_model = model.rbac_entries.property.mapper.class_
             query_filter = (
-                (model.tenant_id == context.tenant_id) |
-                (rbac_model.action.in_(
-                    [constants.ACCESS_SHARED, constants.ACCESS_READONLY]) &
-                 ((rbac_model.target_project == context.tenant_id) |
+                (model.tenant_id == context.project_id) |
+                (rbac_model.action.in_(get_rbac_actions(model)) &
+                 ((rbac_model.target_project == context.project_id) |
                   (rbac_model.target_project == '*'))))
+            # This "group_by" clause will limit the number of registers
+            # returned by the query, avoiding the problem of the low SQL
+            # query cardinality when the RBAC registers are in the requested
+            # project ID.
+            group_by = model.id
         elif hasattr(model, 'shared'):
-            query_filter = ((model.tenant_id == context.tenant_id) |
+            query_filter = ((model.tenant_id == context.project_id) |
                             (model.shared == sql.true()))
         else:
-            query_filter = (model.tenant_id == context.tenant_id)
+            query_filter = (model.tenant_id == context.project_id)
     # Execute query hooks registered from mixins and plugins
     for hook in get_hooks(model):
         query_hook = helpers.resolve_ref(hook.get('query'))
@@ -149,9 +186,12 @@ def query_with_hooks(context, model, field=None, lazy_fields=None):
     if query_filter is not None:
         query = query.filter(query_filter)
 
+    if group_by:
+        query = query.group_by(group_by)
+
     if lazy_fields:
-        for field in lazy_fields:
-            query = query.options(lazyload(field))
+        for lfield in lazy_fields:
+            query = query.options(lazyload(lfield))
     return query
 
 
@@ -219,7 +259,7 @@ def apply_filters(query, model, filters, context=None):
                 rbac = model.rbac_entries.property.mapper.class_
                 matches = [rbac.target_project == '*']
                 if context:
-                    matches.append(rbac.target_project == context.tenant_id)
+                    matches.append(rbac.target_project == context.project_id)
                 # any 'access_as_shared' records that match the
                 # wildcard or requesting tenant
                 is_shared = and_(rbac.action == constants.ACCESS_SHARED,
