@@ -33,14 +33,14 @@ class NeutronException(Exception):
 
     def __init__(self, **kwargs):
         try:
-            super(NeutronException, self).__init__(self.message % kwargs)
+            super().__init__(self.message % kwargs)
             self.msg = self.message % kwargs
         except Exception:
             with excutils.save_and_reraise_exception() as ctxt:
                 if not self.use_fatal_exceptions():
                     ctxt.reraise = False
                     # at least get the core message out if something happened
-                    super(NeutronException, self).__init__(self.message)
+                    super().__init__(self.message)
 
     def __str__(self):
         return self.msg
@@ -177,9 +177,18 @@ class NetworkInUse(InUse):
     network.
 
     :param net_id: The UUID of the network requested.
+    :param reason: Details on why the operation failed. If None, a default
+        reason is used indicating one or more ports still in use
+        on the network.
     """
     message = _("Unable to complete operation on network %(net_id)s. "
-                "There are one or more ports still in use on the network.")
+                "%(reason)s.")
+
+    def __init__(self, **kwargs):
+        if 'reason' not in kwargs:
+            kwargs['reason'] = _("There are one or more ports still in use "
+                                 "on the network")
+        super().__init__(**kwargs)
 
 
 class SubnetInUse(InUse):
@@ -200,7 +209,7 @@ class SubnetInUse(InUse):
         if 'reason' not in kwargs:
             kwargs['reason'] = _("One or more ports have an IP allocation "
                                  "from this subnet")
-        super(SubnetInUse, self).__init__(**kwargs)
+        super().__init__(**kwargs)
 
 
 class SubnetPoolInUse(InUse):
@@ -219,7 +228,7 @@ class SubnetPoolInUse(InUse):
     def __init__(self, **kwargs):
         if 'reason' not in kwargs:
             kwargs['reason'] = _("Two or more concurrent subnets allocated")
-        super(SubnetPoolInUse, self).__init__(**kwargs)
+        super().__init__(**kwargs)
 
 
 class PortInUse(InUse):
@@ -366,10 +375,10 @@ class NoNetworkAvailable(ResourceExhausted):
     """A failure to create a network due to no tenant networks for allocation.
 
     A specialization of the ResourceExhausted exception indicating network
-    creation failed because no tenant network are available for allocation.
+    creation failed because no project network are available for allocation.
     """
     message = _("Unable to create the network. "
-                "No tenant network is available for allocation.")
+                "No project network is available for allocation.")
 
 
 class SubnetMismatchForPort(BadRequest):
@@ -387,9 +396,10 @@ class SubnetMismatchForPort(BadRequest):
 
 class Invalid(NeutronException):
     """A generic base class for invalid errors."""
+
     def __init__(self, message=None):
         self.message = message
-        super(Invalid, self).__init__()
+        super().__init__()
 
 
 class InvalidInput(BadRequest):
@@ -481,7 +491,7 @@ class NetworkTunnelRangeError(NeutronException):
         # Convert tunnel_range tuple to 'start:end' format for display
         if isinstance(kwargs['tunnel_range'], tuple):
             kwargs['tunnel_range'] = "%d:%d" % kwargs['tunnel_range']
-        super(NetworkTunnelRangeError, self).__init__(**kwargs)
+        super().__init__(**kwargs)
 
 
 class PolicyInitError(NeutronException):
@@ -517,7 +527,7 @@ class MultipleExceptions(Exception):
         :param args: Passed onto parent constructor.
         :param kwargs: Passed onto parent constructor.
         """
-        super(MultipleExceptions, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self.inner_exceptions = exceptions
 
 
@@ -552,7 +562,7 @@ class NetworkVlanRangeError(NeutronException):
         # Convert vlan_range tuple to 'start:end' format for display
         if isinstance(kwargs['vlan_range'], tuple):
             kwargs['vlan_range'] = "%d:%d" % kwargs['vlan_range']
-        super(NetworkVlanRangeError, self).__init__(**kwargs)
+        super().__init__(**kwargs)
 
 
 class PhysicalNetworkNameError(NeutronException):
@@ -639,7 +649,7 @@ class InvalidQuotaValue(Conflict):
 
 class InvalidSharedSetting(Conflict):
     message = _("Unable to reconfigure sharing settings for network "
-                "%(network)s. Multiple tenants are using it.")
+                "%(network)s. Multiple projects are using it.")
 
 
 class ExtensionsNotFound(NotFound):
@@ -670,12 +680,12 @@ class DuplicatedExtension(NeutronException):
 
 class DriverCallError(MultipleExceptions):
     def __init__(self, exc_list=None):
-        super(DriverCallError, self).__init__(exc_list or [])
+        super().__init__(exc_list or [])
 
 
 class DeviceIDNotOwnedByTenant(Conflict):
     message = _("The following device_id %(device_id)s is not owned by your "
-                "tenant or matches another tenants router.")
+                "project or matches another project router.")
 
 
 class InvalidCIDR(BadRequest):
@@ -753,7 +763,7 @@ class SubnetPoolDeleteError(BadRequest):
 
 
 class SubnetPoolQuotaExceeded(OverQuota):
-    message = _("Per-tenant subnet pool prefix quota exceeded.")
+    message = _("Per-project subnet pool prefix quota exceeded.")
 
 
 class NetworkSubnetPoolAffinityError(BadRequest):
@@ -771,7 +781,7 @@ class CTZoneExhaustedError(NeutronException):
 
 
 class TenantQuotaNotFound(NotFound):
-    message = _("Quota for tenant %(tenant_id)s could not be found.")
+    message = _("Quota for project %(tenant_id)s could not be found.")
 
 
 class MultipleFilterIDForIPFound(Conflict):
@@ -809,7 +819,7 @@ class PortBindingError(NeutronException):
 
 class ProcessExecutionError(RuntimeError):
     def __init__(self, message, returncode):
-        super(ProcessExecutionError, self).__init__(message)
+        super().__init__(message)
         self.returncode = returncode
 
 
@@ -820,3 +830,13 @@ class InvalidSubnetServiceType(InvalidInput):
 
 class InvalidInputSubnetServiceType(InvalidInput):
     message = _("Subnet service type %(service_type)s is not a string.")
+
+
+class NetworkMTUSubnetConflict(Conflict):
+    """A conflict error due to MTU being invalid on said network.
+
+    :param net_id: The UUID of the network
+    :param    mtu: The minimum MTU required by a subnet for the network
+    """
+    message = _("MTU of %(net_id)s is not valid, subnet requires a "
+                "minimum of %(mtu)s")
