@@ -34,18 +34,6 @@ class NoVRIDAvailable(exceptions.Conflict):
 class HANetworkConcurrentDeletion(exceptions.Conflict):
     message = _("Network for project %(project_id)s concurrently deleted.")
 
-    # NOTE(haleyb): remove fall-back and warning in E+2 release, or when
-    # all callers have been changed to use project_id.
-    def __init__(self, **kwargs):
-        project_id = kwargs.get('project_id')
-        tenant_id = kwargs.get('tenant_id')
-        project_id = project_id or tenant_id
-        if tenant_id:
-            LOG.warning('Keyword tenant_id has been deprecated, use '
-                        'project_id instead')
-        kwargs.setdefault('project_id', project_id)
-        super().__init__(**kwargs)
-
 
 class HANetworkCIDRNotValid(exceptions.NeutronException):
     message = _("The HA Network CIDR specified in the configuration file "
