@@ -15,6 +15,7 @@
 import re
 
 from debtcollector import removals
+from hacking import core
 
 from neutron_lib.hacking import translation_checks
 
@@ -37,15 +38,22 @@ namespace_imports_from_dot = re.compile(r"from[\s]+([\w]+)[.]")
 namespace_imports_from_root = re.compile(r"from[\s]+([\w]+)[\s]+import[\s]+")
 contextlib_nested = re.compile(r"^\s*with (contextlib\.)?nested\(")
 
+assert_equal_none_re = re.compile(
+    r"assertEqual\(.*?,\s+None\)(( |\t)*#.*)?$|assertEqual\(None,")
+assert_is_none_re = re.compile(
+    r"assertIs(Not)?\(.*,\s+None\)(( |\t)*#.*)?$|assertIs(Not)?\(None,")
 
+
+@core.off_by_default
+@core.flake8ext
 def use_jsonutils(logical_line, filename):
     """N521 - jsonutils must be used instead of json.
 
     :param logical_line: The logical line to check.
     :param filename: The file name where the logical line exists.
     :returns: None if the logical line passes the check, otherwise a tuple
-    is yielded that contains the offending index in logical line and a
-    message describe the check validation failure.
+        is yielded that contains the offending index in logical line and a
+        message describe the check validation failure.
     """
     msg = "N521: jsonutils.%(fun)s must be used instead of json.%(fun)s"
 
@@ -63,7 +71,7 @@ def use_jsonutils(logical_line, filename):
     if "json." in logical_line:
         json_funcs = ['dumps(', 'dump(', 'loads(', 'load(']
         for f in json_funcs:
-            pos = logical_line.find('json.%s' % f)
+            pos = logical_line.find(f'json.{f}')
             if pos != -1:
                 yield (pos, msg % {'fun': f[:-1]})
 
@@ -77,54 +85,41 @@ def _check_imports(regex, submatch, logical_line):
 def _check_namespace_imports(failure_code, namespace, new_ns, logical_line,
                              message_override=None):
     if message_override is not None:
-        msg_o = "%s: %s" % (failure_code, message_override)
+        msg_o = f"{failure_code}: {message_override}"
     else:
         msg_o = None
 
     if _check_imports(namespace_imports_from_dot, namespace, logical_line):
-        msg = ("%s: '%s' must be used instead of '%s'.") % (
+        msg = ("{}: '{}' must be used instead of '{}'.").format(
             failure_code,
-            logical_line.replace('%s.' % namespace, new_ns),
+            logical_line.replace(f'{namespace}.', new_ns),
             logical_line)
         return (0, msg_o or msg)
     elif _check_imports(namespace_imports_from_root, namespace, logical_line):
-        msg = ("%s: '%s' must be used instead of '%s'.") % (
+        msg = ("{}: '{}' must be used instead of '{}'.").format(
             failure_code,
             logical_line.replace(
-                'from %s import ' % namespace, 'import %s' % new_ns),
+                f'from {namespace} import ', f'import {new_ns}'),
             logical_line)
         return (0, msg_o or msg)
     elif _check_imports(namespace_imports_dot, namespace, logical_line):
-        msg = ("%s: '%s' must be used instead of '%s'.") % (
+        msg = ("{}: '{}' must be used instead of '{}'.").format(
             failure_code,
             logical_line.replace('import', 'from').replace('.', ' import '),
             logical_line)
         return (0, msg_o or msg)
 
 
-@removals.remove(removal_version='P release')
-def check_oslo_namespace_imports(logical_line):
-    """N523 - Import oslo_ rather than oslo.
-
-    :param logical_line: The logical line to check.
-    :param filename: The file name where the logical line exists.
-    :returns: None if the logical line passes the check, otherwise a tuple
-    is yielded that contains the offending index in logical line and a
-    message describe the check validation failure.
-    """
-    x = _check_namespace_imports('N523', 'oslo', 'oslo_', logical_line)
-    if x is not None:
-        yield x
-
-
+@core.off_by_default
+@core.flake8ext
 def check_no_contextlib_nested(logical_line, filename):
     """N524 - Use of contextlib.nested is deprecated.
 
     :param logical_line: The logical line to check.
     :param filename: The file name where the logical line exists.
     :returns: None if the logical line passes the check, otherwise a tuple
-    is yielded that contains the offending index in logical line and a
-    message describe the check validation failure.
+        is yielded that contains the offending index in logical line and a
+        message describe the check validation failure.
     """
     msg = ("N524: contextlib.nested is deprecated. With Python 2.7 and later "
            "the with-statement supports multiple nested objects. See https://"
@@ -132,60 +127,18 @@ def check_no_contextlib_nested(logical_line, filename):
            "more information.")
 
     if contextlib_nested.match(logical_line):
-        yield(0, msg)
-
-
-def check_python3_xrange(logical_line):
-    """N525 - Do not use xrange.
-
-    :param logical_line: The logical line to check.
-    :returns: None if the logical line passes the check, otherwise a tuple
-    is yielded that contains the offending index in logical line and a
-    message describe the check validation failure.
-    """
-    if re.search(r"\bxrange\s*\(", logical_line):
-        yield(0, "N525: Do not use xrange. Use range, or six.moves.range for "
-                 "large loops.")
-
-
-def check_no_basestring(logical_line):
-    """N526 - basestring is not Python3-compatible.
-
-    :param logical_line: The logical line to check.
-    :returns: None if the logical line passes the check, otherwise a tuple
-    is yielded that contains the offending index in logical line and a
-    message describe the check validation failure.
-    """
-    if re.search(r"\bbasestring\b", logical_line):
-        msg = ("N526: basestring is not Python3-compatible, use "
-               "six.string_types instead.")
-        yield(0, msg)
-
-
-def check_python3_no_iteritems(logical_line):
-    """N527 - Use dict.items() instead of dict.iteritems().
-
-    :param logical_line: The logical line to check.
-    :returns: None if the logical line passes the check, otherwise a tuple
-    is yielded that contains the offending index in logical line and a
-    message describe the check validation failure.
-    """
-    if re.search(r".*\.iteritems\(\)", logical_line):
-        msg = ("N527: Use dict.items() instead of dict.iteritems() to be "
-               "compatible with both Python 2 and Python 3. In Python 2, "
-               "dict.items() may be inefficient for very large dictionaries. "
-               "If you can prove that you need the optimization of an "
-               "iterator for Python 2, then you can use six.iteritems(dict).")
-        yield(0, msg)
+        yield (0, msg)
 
 
+@core.off_by_default
+@core.flake8ext
 def no_mutable_default_args(logical_line):
     """N529 - Method's default argument shouldn't be mutable.
 
     :param logical_line: The logical line to check.
     :returns: None if the logical line passes the check, otherwise a tuple
-    is yielded that contains the offending index in logical line and a
-    message describe the check validation failure.
+        is yielded that contains the offending index in logical line and a
+        message describe the check validation failure.
     """
     msg = "N529: Method's default argument shouldn't be mutable!"
     if mutable_default_args.match(logical_line):
@@ -195,13 +148,15 @@ def no_mutable_default_args(logical_line):
 # Chances are that most projects will need to put an ignore on this rule
 # until they can fully migrate to the lib.
 
+@core.off_by_default
+@core.flake8ext
 def check_neutron_namespace_imports(logical_line):
     """N530 - Direct neutron imports not allowed.
 
     :param logical_line: The logical line to check.
     :returns: None if the logical line passes the check, otherwise a tuple
-    is yielded that contains the offending index in logical line and a
-    message describe the check validation failure.
+        is yielded that contains the offending index in logical line and a
+        message describe the check validation failure.
     """
     x = _check_namespace_imports(
         'N530', 'neutron', 'neutron_lib.', logical_line,
@@ -210,32 +165,52 @@ def check_neutron_namespace_imports(logical_line):
         yield x
 
 
+@core.off_by_default
+@core.flake8ext
 def check_no_eventlet_imports(logical_line):
     """N535 - Usage of Python eventlet module not allowed.
 
     :param logical_line: The logical line to check.
     :returns: None if the logical line passes the check, otherwise a tuple
-    is yielded that contains the offending index in logical line and a
-    message describe the check validation failure.
+        is yielded that contains the offending index in logical line and a
+        message describe the check validation failure.
     """
     if re.match(r'(import|from)\s+[(]?eventlet', logical_line):
         msg = 'N535: Usage of Python eventlet module not allowed'
         yield logical_line.index('eventlet'), msg
 
 
+@removals.remove(message='Use H203 check instead')
+@core.off_by_default
+@core.flake8ext
+def assert_equal_none(logical_line):
+    """N536 - Use assertIsNone."""
+    if assert_equal_none_re.search(logical_line):
+        msg = ("N536: Use assertIsNone rather than assertEqual "
+               "to check for None values")
+        yield logical_line.index('assert'), msg
+
+    if assert_is_none_re.search(logical_line):
+        msg = ("N536: Use assertIsNone or assertIsNotNone rather than "
+               "assertIs or assertIsNone to check for None values.")
+        yield logical_line.index('assert'), msg
+
+
+# TODO(amotoki): Drop this once all neutron related projects
+# have switched to hacking 2.x
 def factory(register):
+    """Hacking check factory for neutron-lib adopter compliant checks.
+
+    Hacking check factory for use with tox.ini. This factory registers all
+    neutron-lib adopter checks consumers should seek to comply with.
+
+    :param register: The function to register the check functions with.
+    :returns: None.
+    """
     register(use_jsonutils)
     register(check_no_contextlib_nested)
-    register(check_python3_xrange)
-    register(check_no_basestring)
-    register(check_python3_no_iteritems)
     register(no_mutable_default_args)
     register(check_neutron_namespace_imports)
-    # TODO(boden) - uncomment this after 0.4.0 ships
-    # register(check_no_eventlet_imports)
-    register(translation_checks.validate_log_translations)
-    register(translation_checks.no_translate_debug_logs)
+    register(translation_checks.no_translate_logs)
     register(translation_checks.check_log_warn_deprecated)
     register(translation_checks.check_raised_localized_exceptions)
-    # TODO(boden) - uncomment this after 0.4.0 ships
-    # register(translation_checks.check_delayed_string_interpolation)
