@@ -17,7 +17,7 @@ import functools
 import re
 import time
 from urllib import parse
-import uuid
+import uuid as uuid_lib
 
 import requests
 
@@ -39,7 +39,8 @@ PLACEMENT_API_WITH_NESTED_RESOURCES = 'placement 1.14'
 PLACEMENT_API_RETURN_PROVIDER_BODY = 'placement 1.20'
 PLACEMENT_API_ERROR_CODE = 'placement 1.23'
 PLACEMENT_API_CONSUMER_GENERATION = 'placement 1.28'
-PLACEMENT_API_LATEST_SUPPORTED = PLACEMENT_API_CONSUMER_GENERATION
+PLACEMENT_API_UPDATE_REPARENT = 'placement 1.37'
+PLACEMENT_API_LATEST_SUPPORTED = PLACEMENT_API_UPDATE_REPARENT
 GENERATION_CONFLICT_RETRIES = 10
 
 
@@ -64,8 +65,7 @@ def _check_placement_api_available(f):
                 # to avoid losing information.
                 raise n_exc.PlacementClientError(
                     msg=exc.response.text.replace('\n', ' '))
-            else:
-                raise
+            raise
     return wrapper
 
 
@@ -77,12 +77,12 @@ def _get_version(openstack_api_version):
 
 class UUIDEncoder(jsonutils.JSONEncoder):
     def default(self, o):
-        if isinstance(o, uuid.UUID):
+        if isinstance(o, uuid_lib.UUID):
             return str(o)
-        return super(UUIDEncoder, self).default(o)
+        return super().default(o)
 
 
-class NoAuthClient(object):
+class NoAuthClient:
     """Placement NoAuthClient for fullstack testing"""
 
     def __init__(self, url):
@@ -127,22 +127,22 @@ class NoAuthClient(object):
         raise ks_exc.HttpError
 
     def get(self, url, endpoint_filter, **kwargs):
-        return self.request('%s%s' % (self.url, url), 'GET', **kwargs)
+        return self.request(f'{self.url}{url}', 'GET', **kwargs)
 
     def post(self, url, json, endpoint_filter, **kwargs):
-        return self.request('%s%s' % (self.url, url), 'POST', body=json,
+        return self.request(f'{self.url}{url}', 'POST', body=json,
                             **kwargs)
 
     def put(self, url, json, endpoint_filter, **kwargs):
-        resp = self.request('%s%s' % (self.url, url), 'PUT', body=json,
+        resp = self.request(f'{self.url}{url}', 'PUT', body=json,
                             **kwargs)
         return resp
 
     def delete(self, url, endpoint_filter, **kwargs):
-        return self.request('%s%s' % (self.url, url), 'DELETE', **kwargs)
+        return self.request(f'{self.url}{url}', 'DELETE', **kwargs)
 
 
-class PlacementAPIClient(object):
+class PlacementAPIClient:
     """Client class for placement ReST API."""
 
     def __init__(self, conf,
@@ -233,8 +233,7 @@ class PlacementAPIClient(object):
                 if e.response.json()[
                         'errors'][0]['code'] == 'placement.concurrent_update':
                     continue
-                else:
-                    raise
+                raise
 
         raise n_exc.PlacementResourceProviderGenerationConflict(
             resource_provider=resource_provider_uuid,
@@ -277,7 +276,8 @@ class PlacementAPIClient(object):
                                                         the same name.
         :returns: The updated resource provider.
         """
-        url = '/resource_providers/%s' % resource_provider['uuid']
+        # pylint: disable=raise-missing-from
+        url = '/resource_providers/{}'.format(resource_provider['uuid'])
         # update does not tolerate if the uuid is repeated in the body
         update_body = resource_provider.copy()
         update_body.pop('uuid')
@@ -314,7 +314,7 @@ class PlacementAPIClient(object):
 
         :param resource_provider_uuid: UUID of the resource provider.
         """
-        url = '/resource_providers/%s' % resource_provider_uuid
+        url = f'/resource_providers/{resource_provider_uuid}'
         self._delete(url)
 
     @_check_placement_api_available
@@ -325,7 +325,8 @@ class PlacementAPIClient(object):
         :raises PlacementResourceProviderNotFound: For failure to find resource
         :returns: The Resource Provider matching the UUID.
         """
-        url = '/resource_providers/%s' % resource_provider_uuid
+        # pylint: disable=raise-missing-from
+        url = f'/resource_providers/{resource_provider_uuid}'
         try:
             return self._get(url).json()
         except ks_exc.NotFound:
@@ -376,7 +377,7 @@ class PlacementAPIClient(object):
             filters['in_tree'] = in_tree
         if uuid:
             filters['uuid'] = uuid
-        url = '%s?%s' % (url, parse.urlencode(filters))
+        url = f'{url}?{parse.urlencode(filters)}'
         return self._get(url).json()
 
     @_check_placement_api_available
@@ -407,7 +408,8 @@ class PlacementAPIClient(object):
                                                              server side.
         :returns: The updated set of inventory records.
         """
-        url = '/resource_providers/%s/inventories' % resource_provider_uuid
+        # pylint: disable=raise-missing-from
+        url = f'/resource_providers/{resource_provider_uuid}/inventories'
         body = {
             'resource_provider_generation': resource_provider_generation,
             'inventories': inventories
@@ -430,16 +432,14 @@ class PlacementAPIClient(object):
                                                    is not found.
         :returns: None.
         """
-        url = '/resource_providers/%s/inventories' % (
-            resource_provider_uuid)
+        url = f'/resource_providers/{resource_provider_uuid}/inventories'
         try:
             self._delete(url)
         except ks_exc.NotFound as e:
             if "No resource provider with uuid" in e.details:
                 raise n_exc.PlacementResourceProviderNotFound(
                     resource_provider=resource_provider_uuid)
-            else:
-                raise
+            raise
 
     @_check_placement_api_available
     def delete_resource_provider_inventory(self, resource_provider_uuid,
@@ -453,20 +453,19 @@ class PlacementAPIClient(object):
         :raises PlacementInventoryNotFound: No inventory of class.
         :returns: None.
         """
-        url = '/resource_providers/%s/inventories/%s' % (
-            resource_provider_uuid, resource_class)
+        url = (f'/resource_providers/{resource_provider_uuid}'
+               f'/inventories/{resource_class}')
         try:
             self._delete(url)
         except ks_exc.NotFound as e:
             if "No resource provider with uuid" in e.details:
                 raise n_exc.PlacementResourceProviderNotFound(
                     resource_provider=resource_provider_uuid)
-            elif "No inventory of class" in e.details:
+            if "No inventory of class" in e.details:
                 raise n_exc.PlacementInventoryNotFound(
                     resource_provider=resource_provider_uuid,
                     resource_class=resource_class)
-            else:
-                raise
+            raise
 
     @_check_placement_api_available
     def get_inventory(self, resource_provider_uuid, resource_class):
@@ -481,20 +480,19 @@ class PlacementAPIClient(object):
                                             for a resource provider.
         :returns: The inventory of the resource class as a dict.
         """
-        url = '/resource_providers/%s/inventories/%s' % (
-            resource_provider_uuid, resource_class)
+        url = (f'/resource_providers/{resource_provider_uuid}/'
+               f'inventories/{resource_class}')
         try:
             return self._get(url).json()
         except ks_exc.NotFound as e:
             if "No resource provider with uuid" in e.details:
                 raise n_exc.PlacementResourceProviderNotFound(
                     resource_provider=resource_provider_uuid)
-            elif _("No inventory of class") in e.details:
+            if _("No inventory of class") in e.details:
                 raise n_exc.PlacementInventoryNotFound(
                     resource_provider=resource_provider_uuid,
                     resource_class=resource_class)
-            else:
-                raise
+            raise
 
     @_check_placement_api_available
     def update_resource_provider_inventory(
@@ -516,8 +514,8 @@ class PlacementAPIClient(object):
                                                              server side.
         :returns: The updated inventory of the resource class as a dict.
         """
-        url = '/resource_providers/%s/inventories/%s' % (
-            resource_provider_uuid, resource_class)
+        url = (f'/resource_providers/{resource_provider_uuid}/'
+               f'inventories/{resource_class}')
         body = inventory
 
         try:
@@ -536,7 +534,7 @@ class PlacementAPIClient(object):
                            provider.
         :returns: All aggregates associated with the resource provider.
         """
-        url = '/resource_providers/%s/aggregates' % resource_provider_uuid
+        url = f'/resource_providers/{resource_provider_uuid}/aggregates'
         return self._put(url, aggregates).json()
 
     @_check_placement_api_available
@@ -549,7 +547,8 @@ class PlacementAPIClient(object):
         :returns: The list of aggregates together with the resource provider
                   generation.
         """
-        url = '/resource_providers/%s/aggregates' % resource_provider_uuid
+        # pylint: disable=raise-missing-from
+        url = f'/resource_providers/{resource_provider_uuid}/aggregates'
         try:
             return self._get(url).json()
         except ks_exc.NotFound:
@@ -570,7 +569,8 @@ class PlacementAPIClient(object):
         :raises PlacementTraitNotFound: If the trait name not found.
         :returns: Evaluates to True if the trait exists.
         """
-        url = '/traits/%s' % name
+        # pylint: disable=raise-missing-from
+        url = f'/traits/{name}'
         try:
             return self._get(url)
         except ks_exc.NotFound:
@@ -583,7 +583,7 @@ class PlacementAPIClient(object):
         :param name: name of the trait to create.
         :returns: The Response object so you may access response headers.
         """
-        url = '/traits/%s' % (name)
+        url = f'/traits/{name}'
         return self._put(url, None)
 
     @_check_placement_api_available
@@ -594,7 +594,8 @@ class PlacementAPIClient(object):
         :raises PlacementTraitNotFound: If the trait did not exist.
         :returns: None.
         """
-        url = '/traits/%s' % (name)
+        # pylint: disable=raise-missing-from
+        url = f'/traits/{name}'
         try:
             self._delete(url)
         except ks_exc.NotFound:
@@ -626,7 +627,8 @@ class PlacementAPIClient(object):
         :returns: The new traits of the resource provider together with the
                   resource provider generation.
         """
-        url = '/resource_providers/%s/traits' % (resource_provider_uuid)
+        # pylint: disable=raise-missing-from
+        url = f'/resource_providers/{resource_provider_uuid}/traits'
         body = {
             'resource_provider_generation': resource_provider_generation,
             'traits': traits
@@ -653,7 +655,8 @@ class PlacementAPIClient(object):
         :returns: The associated traits of the resource provider together
                   with the resource provider generation.
         """
-        url = '/resource_providers/%s/traits' % (resource_provider_uuid)
+        # pylint: disable=raise-missing-from
+        url = f'/resource_providers/{resource_provider_uuid}/traits'
         try:
             return self._get(url).json()
         except ks_exc.NotFound:
@@ -670,7 +673,8 @@ class PlacementAPIClient(object):
                                                    is not found.
         :returns: None.
         """
-        url = '/resource_providers/%s/traits' % (resource_provider_uuid)
+        # pylint: disable=raise-missing-from
+        url = f'/resource_providers/{resource_provider_uuid}/traits'
         try:
             self._delete(url)
         except ks_exc.NotFound:
@@ -692,7 +696,8 @@ class PlacementAPIClient(object):
                                                 is not found.
         :returns: The name of resource class and its set of links.
         """
-        url = '/resource_classes/%s' % (name)
+        # pylint: disable=raise-missing-from
+        url = f'/resource_classes/{name}'
         try:
             return self._get(url).json()
         except ks_exc.NotFound:
@@ -716,7 +721,7 @@ class PlacementAPIClient(object):
         :param name: the name of the resource class to be updated or validated
         :returns: None.
         """
-        url = '/resource_classes/%s' % name
+        url = f'/resource_classes/{name}'
         self._put(url, None)
 
     @_check_placement_api_available
@@ -728,7 +733,8 @@ class PlacementAPIClient(object):
                                                 is not found.
         :returns: None.
         """
-        url = '/resource_classes/%s' % (name)
+        # pylint: disable=raise-missing-from
+        url = f'/resource_classes/{name}'
         try:
             self._delete(url)
         except ks_exc.NotFound:
@@ -742,42 +748,43 @@ class PlacementAPIClient(object):
                               owned by a VM, the VM uuid.
         :returns: All allocation records for the consumer.
         """
-        url = '/allocations/%s' % consumer_uuid
+        url = f'/allocations/{consumer_uuid}'
         return self._get(url).json()
 
-    def update_qos_minbw_allocation(self, consumer_uuid, minbw_alloc_diff,
-                                    rp_uuid):
+    def update_qos_allocation(self, consumer_uuid, alloc_diff):
         """Update allocation for QoS minimum bandwidth consumer
 
         :param consumer_uuid: The uuid of the consumer, in case of bound port
                               owned by a VM, the VM uuid.
-        :param minbw_alloc_diff: A dict which contains the fields to update
-                            for the allocation under the given resource
-                            provider.
-        :param rp_uuid: uuid of the resource provider for which the
-                        allocations are to be updated.
+        :param alloc_diff: A dict which contains RP UUIDs as keys and
+                           corresponding fields to update for the allocation
+                           under the given resource provider.
         """
         for i in range(GENERATION_CONFLICT_RETRIES):
             body = self.list_allocations(consumer_uuid)
             if not body['allocations']:
                 raise n_exc.PlacementAllocationRemoved(consumer=consumer_uuid)
-            if rp_uuid not in body['allocations']:
-                raise n_exc.PlacementAllocationRpNotExists(
-                    resource_provider=rp_uuid, consumer=consumer_uuid)
-            # Count new min_kbps values based on the diff in alloc_diff
-            for drctn, min_kbps_diff in minbw_alloc_diff.items():
-                orig_kbps = body['allocations'][rp_uuid]['resources'][drctn]
-                new_kbps = orig_kbps + min_kbps_diff
-                if new_kbps > 0:
-                    body['allocations'][rp_uuid]['resources'][drctn] = new_kbps
-                else:
-                    # Remove the resource class if the new value for min_kbps
-                    # is 0
-                    resources = body['allocations'][rp_uuid]['resources']
-                    if len(resources) > 1:
-                        resources.pop(drctn, None)
+            # Count new values based on the diff in alloc_diff
+            for rp_uuid, diff in alloc_diff.items():
+                if rp_uuid not in body['allocations']:
+                    raise n_exc.PlacementAllocationRpNotExists(
+                        resource_provider=rp_uuid, consumer=consumer_uuid)
+                for drctn, value in diff.items():
+                    orig_value = body['allocations'][rp_uuid][
+                        'resources'].get(drctn, 0)
+                    new_value = orig_value + value
+                    if new_value > 0:
+                        body['allocations'][rp_uuid]['resources'][
+                            drctn] = new_value
                     else:
-                        body['allocations'].pop(rp_uuid)
+                        # Remove the resource class if the new value is 0
+                        resources = body['allocations'][rp_uuid]['resources']
+                        resources.pop(drctn, None)
+
+            # Remove RPs without any resources
+            body['allocations'] = {
+                rp: alloc for rp, alloc in body['allocations'].items()
+                if alloc.get('resources')}
             try:
                 # Update allocations has no return body, but leave the loop
                 return self.update_allocation(consumer_uuid, body)
@@ -785,8 +792,7 @@ class PlacementAPIClient(object):
                 resp = e.response.json()
                 if resp['errors'][0]['code'] == 'placement.concurrent_update':
                     continue
-                else:
-                    raise
+                raise
         raise n_exc.PlacementAllocationGenerationConflict(
             consumer=consumer_uuid)
 
@@ -797,5 +803,5 @@ class PlacementAPIClient(object):
         :param allocations: Dict in the form described in placement API ref:
                             https://tinyurl.com/yxeuzn6l
         """
-        url = '/allocations/%s' % consumer_uuid
+        url = f'/allocations/{consumer_uuid}'
         self._put(url, allocations)
