@@ -37,11 +37,11 @@ LOG = logging.getLogger(__name__)
 INTERFACE_HASH_LEN = 6
 
 
-def _is_valid_range(val, min, max):
+def _is_valid_range(val, min_val, max_val):
     try:
         # NOTE: use str value to not permit booleans
         val = int(str(val))
-        return min <= val <= max
+        return min_val <= val <= max_val
     except (ValueError, TypeError):
         return False
 
@@ -286,10 +286,11 @@ def get_interface_name(name, prefix='', max_len=constants.DEVICE_NAME_MAX_LEN):
                            "given length for an interface name."))
 
     namelen = max_len - len(prefix) - INTERFACE_HASH_LEN
-    hashed_name = hashlib.sha1(encodeutils.to_utf8(name))
-    new_name = ('%(prefix)s%(truncated)s%(hash)s' %
-                {'prefix': prefix, 'truncated': name[0:namelen],
-                 'hash': hashed_name.hexdigest()[0:INTERFACE_HASH_LEN]})
+    hashed_name = hashlib.new('sha1', usedforsecurity=False)
+    hashed_name.update(encodeutils.to_utf8(name))
+    new_name = (
+        f'{prefix}{name[0:namelen]}'
+        f'{hashed_name.hexdigest()[0:INTERFACE_HASH_LEN]}')
     LOG.info("The requested interface name %(requested_name)s exceeds the "
              "%(limit)d character limitation. It was shortened to "
              "%(new_name)s to fit.",
