@@ -14,7 +14,6 @@
 
 from unittest import mock
 
-import ddt
 from oslo_db import exception as db_exc
 from oslotest import base
 
@@ -58,7 +57,7 @@ callback_id_2 = manager._get_id(callback_2)
 
 
 def callback_raise(*args, **kwargs):
-    raise Exception()
+    raise exceptions.BadRequest()
 
 
 def callback_raise_retriable(*args, **kwargs):
@@ -66,14 +65,13 @@ def callback_raise_retriable(*args, **kwargs):
 
 
 def callback_raise_not_retriable(*args, **kwargs):
-    raise Exception()
+    raise exceptions.BadRequest()
 
 
 def callback_3(resource, event, trigger, payload):
     callback_3.counter += 1
 
 
-@ddt.ddt
 class CallBacksManagerTestCase(base.BaseTestCase):
 
     def setUp(self):
@@ -84,16 +82,21 @@ class CallBacksManagerTestCase(base.BaseTestCase):
         callback_2.counter = 0
         callback_3.counter = 0
 
-    @ddt.data(True, False)
-    def test_subscribe(self, cancellable):
+    def test_subscribe_cancellable(self):
+        self._test_subscribe(True)
+
+    def test_subscribe_uncancellable(self):
+        self._test_subscribe(False)
+
+    def _test_subscribe(self, cancellable):
         self.manager.subscribe(
             callback_1, resources.PORT, events.BEFORE_CREATE,
             cancellable=cancellable)
         self.assertIsNotNone(
             self.manager._callbacks[resources.PORT][events.BEFORE_CREATE])
         self.assertIn(callback_id_1, self.manager._index)
-        self.assertEqual(self.__module__ + '.callback_1-%s' %
-                         hash(callback_1), callback_id_1)
+        self.assertEqual(self.__module__ +
+                         f'.callback_1-{hash(callback_1)}', callback_id_1)
         self.assertEqual(cancellable,
                          self.manager._callbacks[resources.PORT]
                          [events.BEFORE_CREATE][0][2])
@@ -146,8 +149,13 @@ class CallBacksManagerTestCase(base.BaseTestCase):
                              payload=self.event_payload)
         self.assertNotIn(unsub, self.manager._index)
 
-    @ddt.data(True, False)
-    def test_unsubscribe(self, cancellable):
+    def test_unsubscribe_cancellable(self):
+        self._test_unsubscribe(True)
+
+    def test_unsubscribe_uncancellable(self):
+        self._test_unsubscribe(False)
+
+    def _test_unsubscribe(self, cancellable):
         self.manager.subscribe(
             callback_1, resources.PORT, events.BEFORE_CREATE,
             cancellable=cancellable)
@@ -174,8 +182,13 @@ class CallBacksManagerTestCase(base.BaseTestCase):
                           self.manager.unsubscribe,
                           callback_1, None, events.BEFORE_CREATE)
 
-    @ddt.data(True, False)
-    def test_unsubscribe_is_idempotent(self, cancellable):
+    def test_unsubscribe_is_idempotent_cancellable(self):
+        self._test_unsubscribe_is_idempotent(True)
+
+    def test_unsubscribe_is_idempotent_uncancellable(self):
+        self._test_unsubscribe_is_idempotent(False)
+
+    def _test_unsubscribe_is_idempotent(self, cancellable):
         self.manager.subscribe(
             callback_1, resources.PORT, events.BEFORE_CREATE,
             cancellable=cancellable)
