@@ -49,11 +49,11 @@ class TestExceptionToRetryContextManager(_base.BaseTestCase):
 
     def test_inner_exception_preserved_in_retryrequest(self):
         try:
-            exc = ValueError('test')
+            vexc = ValueError('test')
             with db_api.exc_to_retry(ValueError):
-                raise exc
+                raise vexc
         except db_exc.RetryRequest as e:
-            self.assertEqual(exc, e.inner_exc)
+            self.assertEqual(vexc, e.inner_exc)
 
     def test_retries_on_multi_exception_containing_target(self):
         with testtools.ExpectedException(db_exc.RetryRequest):
@@ -106,7 +106,7 @@ class TestDeadLockDecorator(_base.BaseTestCase):
         retry_fixture.cleanUp()
 
     def test_mysql_savepoint_error(self):
-        e = db_exc.DBError("(pymysql.err.InternalError) (1305, u'SAVEPOINT "
+        e = db_exc.DBError("(pymysql.err.InternalError) (1305, 'SAVEPOINT "
                            "sa_savepoint_1 does not exist')")
         self.assertIsNone(self._decorated_function(1, e))
 
@@ -140,7 +140,7 @@ class TestDeadLockDecorator(_base.BaseTestCase):
                       10, 10, 10, 10, 10,
                       10, 10, 10, 10, 10]
 
-        class FakeTime(object):
+        class FakeTime:
             def __init__(self):
                 self.counter = 0
 
@@ -172,26 +172,26 @@ class TestDeadLockDecorator(_base.BaseTestCase):
         context.session.is_active = False
         list_arg = [1, 2, 3, 4]
         dict_arg = {1: 'a', 2: 'b'}
-        l, d = self._context_function(context, list_arg, dict_arg,
-                                      5, db_exc.DBDeadlock())
+        la, da = self._context_function(context, list_arg, dict_arg,
+                                        5, db_exc.DBDeadlock())
         # even though we had 5 failures the list and dict should only
         # be mutated once
-        self.assertEqual(5, len(l))
-        self.assertEqual(3, len(d))
+        self.assertEqual(5, len(la))
+        self.assertEqual(3, len(da))
 
     def test_retry_if_session_inactive_kwargs_not_mutated_after_retries(self):
         context = mock.Mock()
         context.session.is_active = False
         list_arg = [1, 2, 3, 4]
         dict_arg = {1: 'a', 2: 'b'}
-        l, d = self._context_function(context, list_arg=list_arg,
-                                      dict_arg=dict_arg,
-                                      fail_count=5,
-                                      exc_to_raise=db_exc.DBDeadlock())
+        la, da = self._context_function(context, list_arg=list_arg,
+                                        dict_arg=dict_arg,
+                                        fail_count=5,
+                                        exc_to_raise=db_exc.DBDeadlock())
         # even though we had 5 failures the list and dict should only
         # be mutated once
-        self.assertEqual(5, len(l))
-        self.assertEqual(3, len(d))
+        self.assertEqual(5, len(la))
+        self.assertEqual(3, len(da))
 
     def test_retry_if_session_inactive_no_retry_in_active_session(self):
         context = mock.Mock()
