@@ -97,7 +97,7 @@ def dict2str(dic):
     :returns: The dict in str representation that is a k=v command list for
         each item in dic.
     """
-    return ','.join("{}={}".format(key, val)
+    return ','.join(f"{key}={val}"
                     for key, val in sorted(dic.items()))
 
 
@@ -209,8 +209,7 @@ def resolve_ref(ref):
 
 def timecost(f):
     call_id = uuidutils.generate_uuid()
-    message_base = ("Time-cost: call %(call_id)s function %(fname)s ") % {
-                    "call_id": call_id, "fname": f.__name__}
+    message_base = (f"Time-cost: call {call_id} function {f.__name__} ")
     end_message = (message_base + "took %(seconds).3fs seconds to run")
 
     @timeutils.time_it(LOG, message=end_message, min_duration=None)
